local MogIt,mog = ...;
local L = mog.L;

local IsDressableItem = IsDressableItem;
local GetScreenWidth = GetScreenWidth;
local GetScreenHeight = GetScreenHeight;

mog.tooltip = CreateFrame("Frame","MogItTooltip",UIParent);
mog.tooltip:Hide();
mog.tooltip:SetClampedToScreen(true);
mog.tooltip:SetFrameStrata("TOOLTIP");
mog.tooltip:SetBackdrop({
	bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", 
	edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border",
	tile = true, tileSize = 16, edgeSize = 16, 
	insets = { left = 5, right = 5, top = 5, bottom = 5 }
});
mog.tooltip:SetBackdropColor(0,0,0);

mog.tooltip.slots = {
	INVTYPE_HEAD = 0,
	INVTYPE_SHOULDER = 0,
	INVTYPE_CLOAK = 3.4,
	INVTYPE_CHEST = 0,
	INVTYPE_ROBE = 0,
	INVTYPE_WRIST = 0,
	INVTYPE_2HWEAPON = 1.6,
	INVTYPE_WEAPON = 1.6,
	INVTYPE_WEAPONMAINHAND = 1.6,
	INVTYPE_WEAPONOFFHAND = -0.7,
	INVTYPE_SHIELD = -0.7,
	INVTYPE_HOLDABLE = -0.7,
	INVTYPE_RANGED = 1.6,
	INVTYPE_RANGEDRIGHT = 1.6,
	INVTYPE_THROWN = 1.6,
	INVTYPE_HAND = 0,
	INVTYPE_WAIST = 0,
	INVTYPE_LEGS = 0,
	INVTYPE_FEET = 0,
};

mog.tooltip.model = CreateFrame("DressUpModel",nil,mog.tooltip);
mog.tooltip.model:SetPoint("TOPLEFT",mog.tooltip,"TOPLEFT",5,-5);
mog.tooltip.model:SetPoint("BOTTOMRIGHT",mog.tooltip,"BOTTOMRIGHT",-5,5);
mog.tooltip:SetScript("OnShow",function(self)
	if mog.settings.mouse then
		SetOverrideBinding(mog.tooltip,true,"MOUSEWHEELUP","MogItTooltipScrollUp");
		SetOverrideBinding(mog.tooltip,true,"MOUSEWHEELDOWN","MogItTooltipScrollDown");
	end
end);
mog.tooltip:SetScript("OnHide",function(self)
	SetOverrideBinding(mog.tooltip,true,"MOUSEWHEELUP",nil);
	SetOverrideBinding(mog.tooltip,true,"MOUSEWHEELDOWN",nil);
end);

function mog.tooltip.ScrollUp()
	mog.tooltip.model:SetFacing(mog.tooltip.model:GetFacing()+0.3);
end

function mog.tooltip.ScrollDown()
	mog.tooltip.model:SetFacing(mog.tooltip.model:GetFacing()-0.3);
end

mog.tooltip.check = CreateFrame("Frame");
mog.tooltip.check:Hide();
mog.tooltip.check:SetScript("OnUpdate",function(self)
	if mog.tooltip.owner and not (mog.tooltip.owner:IsShown() or mog.tooltip.owner:GetItem()) then
		mog.tooltip:Hide();
		mog.tooltip.item = nil;
	end
	self:Hide();
end);

mog.tooltip.repos = CreateFrame("Frame");
mog.tooltip.repos:Hide();
mog.tooltip.repos:SetScript("OnUpdate",function(self)
	local x,y = mog.tooltip.owner:GetCenter();
	if x and y then
		mog.tooltip:ClearAllPoints();
		local mogpoint,ownerpoint;
		if y/GetScreenHeight() > 0.5 then
			mogpoint = "TOP";
			ownerpoint = "BOTTOM";
		else
			mogpoint = "BOTTOM";
			ownerpoint = "TOP";
		end
		if x/GetScreenWidth() > 0.5 then
			mogpoint = mogpoint.."LEFT";
			ownerpoint = ownerpoint.."LEFT";
		else
			mogpoint = mogpoint.."RIGHT";
			ownerpoint = ownerpoint.."RIGHT";
		end
		mog.tooltip:SetPoint(mogpoint,mog.tooltip.owner,ownerpoint);
		self:Hide();
	end
end);

function mog.tooltip.ShowItem(self)
	if mog.settings.tt then
		local _,item = self:GetItem();
		if item then
			if mog.tooltip.item ~= item then
				mog.tooltip.item = item;
				local _,_,quality,_,_,class,subclass,_,slot = GetItemInfo(item);
				if (not mog.settings.mog or quality == 2 or quality == 3 or quality == 4) and mog.tooltip.slots[slot] and IsDressableItem(item) then
					mog.tooltip.model:SetFacing(mog.tooltip.slots[slot]-(mog.settings.rotate and 0.5 or 0));
					--mog.tooltip:SetWidth(mog.tooltip.slots[slot][5]);
					--mog.tooltip:SetHeight(mog.tooltip.slots[slot][6]);
					--mog.tooltip.model:SetPosition(mog.tooltip.slots[slot][2]*UIParent:GetEffectiveScale(),mog.tooltip.slots[slot][3]*UIParent:GetEffectiveScale(),mog.tooltip.slots[slot][4]*UIParent:GetEffectiveScale());
					mog.tooltip:Show();
					mog.tooltip.owner = self;
					mog.tooltip.repos:Show();
					if mog.settings.ttDress then
						mog.tooltip.model:Dress();
					else
						mog.tooltip.model:Undress();
					end
					mog.tooltip.model:TryOn(item);
				else
					mog.tooltip:Hide();
				end
			end
		else
			mog.tooltip:Hide();
		end
	end
end

function mog.tooltip.HideItem(self)
	mog.tooltip.check:Show();
end

GameTooltip:HookScript("OnTooltipSetItem",mog.tooltip.ShowItem);
GameTooltip:HookScript("OnHide",mog.tooltip.HideItem);
if AtlasLootTooltipTEMP then
	AtlasLootTooltipTEMP:HookScript("OnTooltipSetItem",mog.tooltip.ShowItem);
	AtlasLootTooltipTEMP:HookScript("OnHide",mog.tooltip.HideItem);
end

mog.tooltip.rotate = CreateFrame("Frame",nil,mog.tooltip);
mog.tooltip.rotate:Hide();
mog.tooltip.rotate:SetScript("OnUpdate",function(self,elapsed)
	mog.tooltip.model:SetFacing(mog.tooltip.model:GetFacing() + elapsed);
end);